aboutsummaryrefslogtreecommitdiff
path: root/alacritty/src/logging.rs
diff options
context:
space:
mode:
authorChristian Duerr <contact@christianduerr.com>2023-11-08 07:03:24 +0100
committerChristian Duerr <contact@christianduerr.com>2023-11-11 20:33:06 +0100
commit2f097dac5c78a01bdb020c982a09867b3213a69b (patch)
treef751637a5d4eff5a151273b3bbc7c083d2ed8fc5 /alacritty/src/logging.rs
parent683b5a2cb47579560ed272dc1a4818507dbd30c7 (diff)
downloadr-alacritty-2f097dac5c78a01bdb020c982a09867b3213a69b.tar.gz
r-alacritty-2f097dac5c78a01bdb020c982a09867b3213a69b.tar.bz2
r-alacritty-2f097dac5c78a01bdb020c982a09867b3213a69b.zip
Add `--option` argument to `create-window`
This patch adds a new CLI parameter to the `create-window` subcommand, matching the existing `--option` parameter when creating a new Alacritty instance. This parameter allows setting up the initial window configuration from the CLI without having to call `alacritty msg config`, making sure that all options are set appropriately right from the start. Closes #6238.
Diffstat (limited to 'alacritty/src/logging.rs')
-rw-r--r--alacritty/src/logging.rs7
1 files changed, 4 insertions, 3 deletions
diff --git a/alacritty/src/logging.rs b/alacritty/src/logging.rs
index 5366829f..6bede4e7 100644
--- a/alacritty/src/logging.rs
+++ b/alacritty/src/logging.rs
@@ -20,8 +20,8 @@ use crate::cli::Options;
use crate::event::{Event, EventType};
use crate::message_bar::{Message, MessageType};
-/// Logging target for per-window config error messages.
-pub const LOG_TARGET_WINDOW_CONFIG: &str = "alacritty_log_window_config";
+/// Logging target for IPC config error messages.
+pub const LOG_TARGET_IPC_CONFIG: &str = "alacritty_log_window_config";
/// Name for the environment variable containing the log file's path.
const ALACRITTY_LOG_ENV: &str = "ALACRITTY_LOG";
@@ -42,7 +42,7 @@ static EXTRA_LOG_TARGETS: Lazy<Vec<String>> = Lazy::new(|| {
/// List of targets which will be logged by Alacritty.
const ALLOWED_TARGETS: &[&str] = &[
- LOG_TARGET_WINDOW_CONFIG,
+ LOG_TARGET_IPC_CONFIG,
LOG_TARGET_CONFIG,
"alacritty_config_derive",
"alacritty_terminal",
@@ -50,6 +50,7 @@ const ALLOWED_TARGETS: &[&str] = &[
"crossfont",
];
+/// Initialize the logger to its defaults.
pub fn initialize(
options: &Options,
event_proxy: EventLoopProxy<Event>,